@@ -216,7 +216,7 @@ use Glib::Object::Subclass Gscan2pdf::Dialog::, signals => {
     ),
   ];
 
-our $VERSION = '1.2.6';
+our $VERSION = '1.2.7';
 
 my ( $d, $d_sane, $logger, $tooltips );
 my $tolerance = 1;
@@ -265,9 +265,12 @@ sub INIT_INSTANCE {
     $vbox->pack_start( $self->{notebook}, TRUE, TRUE, 0 );
 
     # Notebook page 1
+    my $scwin = Gtk2::ScrolledWindow->new;
+    $self->{notebook}->append_page( $scwin, $d->get('Page Options') );
+    $scwin->set_policy( 'automatic', 'automatic' );
     my $vbox1 = Gtk2::VBox->new;
     $self->{vbox} = $vbox1;
-    $self->{notebook}->append_page( $vbox1, $d->get('Page Options') );
+    $scwin->add_with_viewport($vbox1);
 
     # Frame for # pages
     my $framen = Gtk2::Frame->new( $d->get('# Pages') );
@@ -542,11 +545,6 @@ sub INIT_INSTANCE {
     $hboxb->pack_end( $cbutton, FALSE, FALSE, 0 );
     $cbutton->signal_connect( clicked => sub { $self->hide; } );
 
-    $self->signal_connect(
-        check_resize => sub {
-            Glib::Idle->add( sub { $self->resize( 1, 1 ); } );
-        }
-    );
     return $self;
 }
 
@@ -692,7 +690,8 @@ sub show {
     my $self = shift;
     $self->signal_chain_from_overridden;
     $self->{framex}->hide_all;
-    if ( defined $self->{combobp}->get_active_text
+    if (    defined $self->{combobp}
+        and defined $self->{combobp}->get_active_text
         and $self->{combobp}->get_active_text ne $d->get('Manual') )
     {
         $self->hide_geometry( $self->get('available-scan-options') );
@@ -1175,7 +1174,7 @@ sub multiple_values_button_callback {
 
 sub value_for_active_option {
     my ( $self, $value, $opt ) = @_;
-    return defined $value and not $opt->{cap} & SANE_CAP_INACTIVE;
+    return ( defined $value and not $opt->{cap} & SANE_CAP_INACTIVE );
 }
 
 # display Goo::Canvas with graph
@@ -1520,6 +1519,29 @@ sub make_progress_string {
     return sprintf $d->get('Scanning page %d'), $i;
 }
 
+sub add_to_current_scan_options {
+    my ( $self, $option, $val ) = @_;
+    my $current = $self->{current_scan_options};
+    if ( not defined $current ) {
+        $current = [];
+    }
+
+    # Config::General flattens an array of hashes with 1 entry to a hash,
+    # so we must check for this
+    elsif ( ref($current) eq 'HASH' ) {
+        my %hash = %{$current};
+        $current = [ \%hash ];
+    }
+
+    # Cache option
+    push @{$current}, { $option->{name} => $val };
+
+    # Note any duplicate options, keeping only the last entry.
+    $self->{current_scan_options} =
+      Gscan2pdf::Scanner::Options::prune_duplicates($current);
+    return;
+}
+
 1;
 
 __END__
