@@ -10,7 +10,7 @@ use HTML::Entities;
 use Encode;
 use English qw( -no_match_vars );    # for $PROCESS_ID
 
-our $VERSION = '1.2.6';
+our $VERSION = '1.2.7';
 
 my ( $exe, $installed, $setup, $logger );
 
@@ -54,23 +54,38 @@ sub setup {
 }
 
 sub hocr {
-    my ( $class, $file, $language, $loggr, $pidfile ) = @_;
+    my ( $class, %options ) = @_;
     my ( $png, $cmd );
-    if ( not $setup ) { Gscan2pdf::Ocropus->setup($loggr) }
+    if ( not $setup ) { Gscan2pdf::Ocropus->setup( $options{logger} ) }
 
-    if ( $file !~ /[.](?:png|jpg|pnm)$/xsm ) {
+    if (   ( $options{file} !~ /[.](?:png|jpg|pnm)$/xsm )
+        or ( defined $options{threshold} and $options{threshold} ) )
+    {
 
         # Temporary filename for new file
         $png = File::Temp->new( SUFFIX => '.png' );
         my $image = Image::Magick->new;
-        $image->Read($file);
-        $image->Write( filename => $png );
+        $image->Read( $options{file} );
+
+        my $x;
+        if ( defined $options{threshold} and $options{threshold} ) {
+            $logger->info("thresholding at $options{threshold} to $png");
+            $image->BlackThreshold( threshold => "$options{threshold}%" );
+            $image->WhiteThreshold( threshold => "$options{threshold}%" );
+            $x = $image->Quantize( colors => 2 );
+            $x = $image->Write( depth => 1, filename => $png );
+        }
+        else {
+            $logger->info("writing temporary image $png");
+            $image->Write( filename => $png );
+        }
+        if ("$x") { $logger->warn($x) }
     }
     else {
-        $png = $file;
+        $png = $options{file};
     }
-    if ($language) {
-        $cmd = "tesslanguage=$language $exe $png";
+    if ( $options{language} ) {
+        $cmd = "tesslanguage=$options{language} $exe $png";
     }
     else {
         $cmd = "$exe $png";
@@ -79,9 +94,10 @@ sub hocr {
 
     # decode html->utf8
     my $output;
-    if ( defined $pidfile ) {
+    if ( defined $options{pidfile} ) {
         ( $output, undef ) =
-          Gscan2pdf::Document::open_three("echo $PROCESS_ID > $pidfile;$cmd");
+          Gscan2pdf::Document::open_three(
+            "echo $PROCESS_ID > $options{pidfile};$cmd");
     }
     else {
         ( $output, undef ) = Gscan2pdf::Document::open_three($cmd);
